#!/bin/bash

update-list() {
    is_root
    printf "${GREEN}%s${CLEAR}\n" "Updating list..."
    sleep 0.5
    download "$REPO/lpkgbuild-$BIT.list" "$LIST"
    exit 0
}

repo-list() {
    if [ -f "$LIST" ]; then
        cut -d\  -f2 "$LIST"
    else
        if [ "$1" = "only" ]; then
            echo "Please update list first"
            exit 3
        fi
    fi
}

diff-list() {
    for pkg in "$DIR_RM"/**; do
        pkg=$(echo "$pkg" | cut -d/ -f6)
        if $COLOR; then
            [ -f "$LIST" ] && grep -q "$pkg" "$LIST" || printf "${YELLOW}%s${CLEAR}\n" "$pkg"
        else
            [ -f "$LIST" ] && grep -q "$pkg" "$LIST" || echo -e "$pkg"
        fi
    done
}

installed-list() {
    if [ "$1" = "only" ]; then
        lsdir=$(ls -1 "$DIR_RM")
        printf "${GREEN}%s${CLEAR}\n" "$lsdir"
    else
        if [ -f "$LIST" ]; then
            while IFS= read -r pkg; do
                if $COLOR; then
                    [ -f "$DIR_RM/$pkg" ] && printf "${GREEN}%s${CLEAR}\n" "$pkg" || echo "$pkg"
                else
                    [ -f "$DIR_RM/$pkg" ] || continue
                    echo "$pkg"
                fi
            done < <(cut -d\  -f2 "$LIST")
        fi
    fi
}

list() {
    type=$1
    if [ "$COLOR" = false ] && [ "$type" = "" ]; then
        type=raw
    fi
    case $type in
        installed) installed-list only;;
        repo) repo-list only;;
        diff) diff-list;;
        raw) repo-list; diff-list;;
        *) installed-list; diff-list;;
    esac
    exit 0
}
