#!/bin/bash

install_pkg() {
    STATUS=""
    dir_pkg="/tmp/$package"
    tar_pkg="/tmp/$package.tar.gz"
    printf "${GREEN}%s %s...${CLEAR}\n" "installing" "$package"

    is_available "$package"
    if $AVAIL; then
        download "$REPO/$BIT/$package.tar.gz" "$tar_pkg"
        [ -f "/tmp/$package.tar.gz" ] && log info downloaded

        if tar -xf /tmp/"$package".tar.gz -C /tmp; then
            log info uncompressed
        else
            return 1
        fi

        if grep -q "Install" "$dir_pkg/install.sh"; then
            # shellcheck disable=SC1091
            source "$dir_pkg/install.sh"
            Install
            grep -q "Verify" "$dir_pkg/install.sh" && Verify
        else
            log info "Old install. Unknown STATUS"
        fi
    else
        STATUS=false
    fi

    if $STATUS && [ -n "$STATUS" ]; then
        # Write remove file
        echo "#!/bin/bash" > "$DIR_RM/$package"
        if grep -q "Remove" "$dir_pkg/install.sh"; then
            declare -f Remove >> "$DIR_RM/$package"
            if grep -q "Verify" "$dir_pkg/install.sh"; then
                declare -f Verify >> "$DIR_RM/$package"
            fi
        fi
        if [ "$(cat "$DIR_RM/$package")" = "#!/bin/bash" ]; then
            # Cancel remove file
            log warning "Remove() and Verify() not found!"
            rm "$DIR_RM/$package"
        fi
        # Clean
        unset -f Install Remove Verify
        log info "$package installed"
    elif ! $STATUS && [ -n "$STATUS" ]; then
        log info "$package not installed"
    else
        log info "Unknown status of $package"
    fi
    rm -rf "/tmp/$package"*
}

remove_pkg() {
    STATUS=""
    printf "${GREEN}%s %s...${CLEAR}\n" "removing" "$package"
    rmpkg="$DIR_RM/$package"
    if [ -f "$rmpkg" ]; then
        if grep -q "Remove" "$rmpkg"; then
            # shellcheck disable=SC1090
            source "$rmpkg"
            Remove
            Verify
            unset -f Install Remove Verify
            log info "$package removed"
            if ! $STATUS && [ -n "$STATUS" ]; then
                rm "$rmpkg"
            fi
        else
            log info "Old remove. Unknown STATUS"
            $rmpkg
        fi
    else
        log warning "$package has not instructions to remove it"
        STATUS=true
    fi
}


parse_pkgs() {
    is_root
    action="$1_pkg"
    if [ "$1" = "install" ]; then
        action_str_installed="Installed"
        action_str_uninstalled="Not installed"
        installed_color="${GREEN}"
        uninstalled_color="${RED}"
    elif [ "$1" = "remove" ]; then
        action_str_uninstalled="Removed"
        action_str_installed="Not removed"
        installed_color="${RED}"
        uninstalled_color="${GREEN}"

    fi
    action_str_unknown="Unknown"
    unknown_color="${YELLOW}"
    code_exit=0
    installed=()
    uninstalled=()
    unknown=()
    ended=()
    duplicated=false
    shift 1
    for package in "$@"; do
        for i in "${ended[@]}"; do
            if [ "$i" = "$package" ]; then
                duplicated=true
                break
            fi
        done
        if ! $duplicated; then
            $action "$package"
            if [ "$action" = "install_pkg" ]; then
                if [ -z "$STATUS" ]; then
                    unknown+=("$package")
                else
                    if $STATUS; then
                        installed+=("$package")
                    else
                        uninstalled+=("$package")
                    fi
                fi
            elif [ "$action" = "remove_pkg" ]; then
                if [ -z "$STATUS" ]; then
                    unknown+=("$package")
                else
                    if ! $STATUS; then
                        uninstalled+=("$package")
                    else
                        installed+=("$package")
                    fi
                fi
            fi
            ended+=("$package")
        fi
    done
    printf "\n"
    if ! [ ${#installed[@]} -eq 0 ]; then
        printf "${installed_color}%s: ${CLEAR}%s\n" "$action_str_installed" "${installed[*]}"
    fi
    if [ ${#uninstalled[@]} -ne 0 ]; then
        printf "${uninstalled_color}%s: ${CLEAR}%s\n" "$action_str_uninstalled" "${uninstalled[*]}"
    fi
    if [ ${#unknown[@]} -ne 0 ]; then
        printf "${unknown_color}%s: ${CLEAR}%s\n" "$action_str_unknown" "${unknown[*]}"
    fi
    exit "$code_exit"
}
